var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);

// src/code-extractor.ts
var _CodeExtractor = class _CodeExtractor {
  /**
   * Constructs a CodeExtractor instance.
   *
   * @param {string} code - The code string to scan for templated blocks.
   * @param {CodeExtractorOptions} [options] - Configuration options to include or exclude certain keywords.
   */
  constructor(code, options) {
    __publicField(this, "code");
    __publicField(this, "options");
    this.code = code;
    this.options = { ..._CodeExtractor.defaultOptions, ...options };
  }
  /**
   * Extracts templated blocks of code based on the provided options.
   *
   * @returns {string[]} An array containing a single string with the full templated block including specified inclusions.
   */
  extract() {
    const packageMatch = this.getPackageMatch();
    const importStatements = this.getImportStatements();
    const constStatements = this.getConstStatements();
    const varStatements = this.getVarStatements();
    const typeStatements = this.getTypeStatements();
    const templRegex = this.options.goExportedOnly ? _CodeExtractor.exportedTemplRegex : _CodeExtractor.allTemplRegex;
    const matches = this.getAllMatches(templRegex);
    const templBlocks = matches.map((match) => this.extractTemplBlock(match.index)).filter(Boolean);
    const allCode = [
      packageMatch ? packageMatch[0] : "",
      ...importStatements,
      ...constStatements,
      ...varStatements,
      ...typeStatements,
      ...templBlocks
    ].filter(Boolean).join("\n\n");
    return [allCode];
  }
  getPackageMatch() {
    return this.options.goPackage ? this.code.match(_CodeExtractor.packageRegex) : null;
  }
  getImportStatements() {
    return this.options.goImports ? this.code.match(_CodeExtractor.importRegex) ?? [] : [];
  }
  getConstStatements() {
    return this.options.goConsts ? this.code.match(_CodeExtractor.constRegex) ?? [] : [];
  }
  getVarStatements() {
    return this.options.goVars ? this.code.match(_CodeExtractor.varRegex) ?? [] : [];
  }
  getTypeStatements() {
    return this.options.goTypes ? this.code.match(_CodeExtractor.typeRegex) ?? [] : [];
  }
  extractTemplBlock(startIndex) {
    let braceCount = 0;
    let endIndex = startIndex;
    while (this.code[endIndex] !== "{" && endIndex < this.code.length) {
      endIndex++;
    }
    const startBraceIndex = endIndex;
    for (; endIndex < this.code.length; endIndex++) {
      if (this.code[endIndex] === "{") braceCount++;
      if (this.code[endIndex] === "}") braceCount--;
      if (braceCount === 0) break;
    }
    if (braceCount === 0) {
      return this.code.slice(startIndex, endIndex + 1);
    }
    return null;
  }
  getAllMatches(regex) {
    const matches = [];
    let match;
    while ((match = regex.exec(this.code)) !== null) {
      matches.push(match);
    }
    return matches;
  }
};
__publicField(_CodeExtractor, "defaultOptions", {
  goExportedOnly: false,
  goPackage: true,
  goImports: true,
  goVars: false,
  goConsts: false,
  goTypes: false
});
__publicField(_CodeExtractor, "packageRegex", /package\s+\w+/);
__publicField(_CodeExtractor, "importRegex", /import\s+\(.*?\)|import\s+.*?;/gs);
__publicField(_CodeExtractor, "constRegex", /const\s+(?:\([^]*?\)|[^\n;]+(;\s*)?)/gs);
__publicField(_CodeExtractor, "varRegex", /var\s+(?:\([^]*?\)|[^\n;]+(;\s*)?)/gs);
__publicField(_CodeExtractor, "typeRegex", /type\s+(?:\([^)]*\)|\w+\s+struct\s+\{[^}]*\}|[^\n;]+;)/gs);
__publicField(_CodeExtractor, "exportedTemplRegex", /templ\s+([A-Z][a-zA-Z]*)\s*\([^)]*\)\s*\{[^}]*\}/gs);
__publicField(_CodeExtractor, "allTemplRegex", /templ\s+\w+\s*\([^)]*\)\s*\{[^}]*\}/gs);
var CodeExtractor = _CodeExtractor;
export {
  CodeExtractor
};
