import type { CachedFile, PluginConfig } from './types';
/**
 * Updates the cache for a specific file by reading its content.
 * @param cache - The cache object to update.
 * @param filePath - The path of the file to read.
 */
export declare function updateFilesCache(cache: Record<string, CachedFile>, filePath: string): Promise<void>;
/**
 * Updates the cache for all HTML and Templ files in a directory.
 * @param cache - The cache object to update.
 * @param directory - The directory to scan for files.
 */
export declare function updateCacheForDirectory(cache: Record<string, CachedFile>, directory: string): Promise<void>;
/**
 * Retrieves the content of a cached file or updates the cache if necessary.
 *
 * @param {Record<string, CachedFile>} fileCache - The file cache.
 * @param {string} filePath - The path of the file to retrieve.
 * @param {string} defaultContent - The default content if the file is not cached.
 * @returns {string} - The content of the cached file or the default content.
 */
export declare function getCachedFileContent(fileCache: Record<string, CachedFile>, filePath: string, defaultContent: string): string;
/**
 * Watches for changes in a file and adds the file to the watched files list.
 *
 * @param {Record<string, Set<string>>} watchedMdFiles - The watched markdown files.
 * @param {string} filePath - The path of the file to watch.
 * @param {string} id - The id of the markdown file.
 */
export declare function watchFileChanges(watchedMdFiles: Record<string, Set<string>>, filePath: string, id: string): void;
/**
 * Checks if the required binaries are installed on the system.
 * @param binaries - The list of binaries to check.
 */
export declare function checkBinaries(binaries: string[]): void;
/**
 * Executes a command synchronously.
 * @param command - The command string to execute.
 */
export declare function executeCommandSync(command: string): void;
/**
 * Executes a command to generate HTML files and then updates the file cache and invalidates modules.
 * @param command - The command string to execute.
 * @param serverRoot - The root directory of the server.
 * @param finalOptions - The final options for the plugin.
 * @param fileCache - The cache for file content.
 * @param watchedMdFiles - The watched markdown files.
 * @param server - The Vite server instance.
 * @param isFirstServerRun - Flag to indicate if this is from the first run of the server.
 */
export declare function executeAndUpdateCache(command: string, serverRoot: string, finalOptions: PluginConfig, fileCache: Record<string, CachedFile>, watchedMdFiles: Record<string, Set<string>>, server: any, isFirstServerRun?: boolean): Promise<void>;
/**
 * Escapes special characters in a string to make it safe for inclusion in a JSON string,
 * including replacing single quotes with escaped double quotes.
 *
 * @param {string} str - The input string to be escaped.
 * @returns {string} - The escaped string, safe for inclusion in JSON.
 *
 * @example
 * const unsafeString = 'This is a "test" string with \\ special characters \n and newlines.';
 * const safeString = escapeForJSON(unsafeString);
 * console.log(safeString); // Output: This is a \"test\" string with \\ special characters \\n and newlines.
 */
export declare function escapeForJSON(str: string): string;
/**
 * Unescapes a string that was previously escaped for JSON,
 * converting escaped sequences back to their original characters.
 *
 * @param {string} str - The input string to be unescaped.
 * @returns {string} - The unescaped string.
 *
 * @example
 * const escapedString = 'This is a \\"test\\" string with \\\\ special characters \\n and newlines.';
 * const unescapedString = unescapeFromJSON(escapedString);
 * console.log(unescapedString); // Output: This is a "test" string with \ special characters \n and newlines.
 */
export declare function unescapeFromJSON(str: string): string;
/**
 * Extracts the inner code from templated blocks.
 *
 * This function takes an array of templated blocks and extracts only the inner code within the braces.
 *
 * @param {string[]} templBlocks - An array of strings, each containing a full templated block.
 * @returns {string[]} An array of strings, each containing only the inner code of the templated block.
 *
 * @example
 * const templBlocks = [
 *   "package main\\n\\nimport (\\n\\"fmt\\"\\n\\"log\\"\\n)\\ntempl AlertDemo() {\\n\\t@alertCss()\\n\\t@alert(\\"Success\\", \\"Files were successfully uploaded\\")\\n}"
 * ];
 * const result = extractInnerCode(templBlocks);
 * console.log(result);
 * // Output:
 * // [
 * //   "@alertCss()\\n  @alert(\\"Success\\", \\"Files were successfully uploaded\\")"
 * // ]
 */
export declare function extractInnerCode(templBlocks: string[]): string[];
